"use strict";
/*
 * Copyright (C) 2017, 2018 TypeFox and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
const protocol_translation_1 = require("./protocol-translation");
const debounce = require("p-debounce");
class FileDiagnostics {
    constructor(uri, publishDiagnostics) {
        this.uri = uri;
        this.publishDiagnostics = publishDiagnostics;
        this.diagnosticsPerKind = new Map();
        this.firePublishDiagnostics = debounce(() => {
            const diagnostics = this.getDiagnostics();
            this.publishDiagnostics({ uri: this.uri, diagnostics });
        }, 50);
    }
    update(kind, diagnostics) {
        this.diagnosticsPerKind.set(kind, diagnostics.map(protocol_translation_1.toDiagnostic));
        this.firePublishDiagnostics();
    }
    getDiagnostics() {
        const result = [];
        for (const value of this.diagnosticsPerKind.values()) {
            result.push(...value);
        }
        return result;
    }
}
class DiagnosticEventQueue {
    constructor(publishDiagnostics, logger) {
        this.publishDiagnostics = publishDiagnostics;
        this.logger = logger;
        this.diagnostics = new Map();
    }
    updateDiagnostics(kind, event) {
        if (!event.body) {
            this.logger.error(`Received empty ${event.event} diagnostics.`);
            return;
        }
        const { file } = event.body;
        const diagnostics = this.diagnostics.get(file) || new FileDiagnostics(protocol_translation_1.pathToUri(file), this.publishDiagnostics);
        diagnostics.update(kind, event.body.diagnostics);
        this.diagnostics.set(file, diagnostics);
    }
}
exports.DiagnosticEventQueue = DiagnosticEventQueue;
//# sourceMappingURL=diagnostic-queue.js.map